aboutsummaryrefslogtreecommitdiffstats
path: root/native/jni/src
diff options
context:
space:
mode:
Diffstat (limited to 'native/jni/src')
-rw-r--r--native/jni/src/defines.h6
-rw-r--r--native/jni/src/proximity_info_state.cpp4
-rw-r--r--native/jni/src/proximity_info_state.h2
3 files changed, 6 insertions, 6 deletions
diff --git a/native/jni/src/defines.h b/native/jni/src/defines.h
index 38090275f..631b31f72 100644
--- a/native/jni/src/defines.h
+++ b/native/jni/src/defines.h
@@ -208,9 +208,9 @@ static inline void prof_out(void) {
#define DEBUG_CORRECTION false
#define DEBUG_CORRECTION_FREQ false
#define DEBUG_WORDS_PRIORITY_QUEUE false
-#define DEBUG_SAMPLING_POINTS true
-#define DEBUG_POINTS_PROBABILITY true
-#define DEBUG_DOUBLE_LETTER true
+#define DEBUG_SAMPLING_POINTS false
+#define DEBUG_POINTS_PROBABILITY false
+#define DEBUG_DOUBLE_LETTER false
#ifdef FLAG_FULL_DBG
#define DEBUG_GEO_FULL true
diff --git a/native/jni/src/proximity_info_state.h b/native/jni/src/proximity_info_state.h
index 5f968e17a..a986e2080 100644
--- a/native/jni/src/proximity_info_state.h
+++ b/native/jni/src/proximity_info_state.h
@@ -196,7 +196,7 @@ class ProximityInfoState {
// Returns angle of three points. x, y, and z are indices.
float getPointsAngle(const int index0, const int index1, const int index2) const;
- float getHighestProbabilitySequence(int *const codePointBuf) const;
+ float getMostProbableCharSequence(int *const codePointBuf) const;
float getProbability(const int index, const int charCode) const;
diff --git a/native/jni/src/proximity_info_state.cpp b/native/jni/src/proximity_info_state.cpp
index a1e20cfeb..78791757f 100644
--- a/native/jni/src/proximity_info_state.cpp
+++ b/native/jni/src/proximity_info_state.cpp
@@ -1143,9 +1143,9 @@ bool ProximityInfoState::suppressCharProbabilities(const int index0, const int i
return true;
}
// Get a word that is detected by tracing highest probability sequence into codePointBuf and
// returns probability of generating the word.
-float ProximityInfoState::getHighestProbabilitySequence(int *const codePointBuf) const {
+float ProximityInfoState::getMostProbableCharSequence(int *const codePointBuf) const {
static const float DEMOTION_LOG_PROBABILITY = 0.3f;
int index = 0;
float sumLogProbability = 0.0f;
@@ -1143,9 +1143,9 @@ bool ProximityInfoState::suppressCharProbabilities(const int index0, const int i
return true;
}
-// Get a word that is detected by tracing highest probability sequence into codePointBuf and
+// Get a word that is detected by tracing the most probable char sequence into codePointBuf and
// returns probability of generating the word.